# Prerequisites
The orchestrator backend has the following requirements

### Backend
For the backend you need the following packages:

* Python >= 3.11
* Postgres >= 14

### Optional dependencies
* Redis
* Docker
